mysql.exceptions.internal

Package mysql :: Package exceptions :: Module internal |
[hide private]
[frames] | no frames]

# Module internal

source code
Internal errors from the MySQL Python code.

Classes | [hide private]
`` | Not_Connected_Error Tried to run a command when no connection is established.
`` | Data_Truncated Data was truncated in the last fetch.
`` | Affected_Rows_Unavailable The number of affected rows is not available.
`` | Result_Unbuffered_Error Attempted to call a method that requires the results to be buffered (stored) locally.
`` | Result_Closed_Error Attempted to use a result object that has been closed.
`` | No_Statement_Info_Error Information is not available for the last statement when using the mysql.connection.Connection.last_statement_info method.
`` | No_Insert_ID_Error The last insert ID is not available when calling the mysql.connection.Connection.last_insert_id method.
`` | No_More_Results No more results are available in the mysql.connection.Connection.next_result method.
`` | No_More_Rows The last row was reached in the mysql.result.Result.fetch_row method.
`` | Statement_Closed_Error Attempted to use a statement object that has been closed.
`` | Connected_Error Attempted to use a command that cannot be used while connected.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.2 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.2 $'